@@ -10,51 +10,60 @@ import warnings
 from builtins import range, str
 
 from .exceptions import (
-    AuthenticationError, AuthorizationError, ClientError, ConflictError,
-    ConnectionError, InputDataError, NotFoundError, RetryError, TransportError,
-    UnknownError)
+    AuthenticationError,
+    AuthorizationError,
+    ClientError,
+    ConflictError,
+    ConnectionError,
+    InputDataError,
+    NotFoundError,
+    RetryError,
+    TransportError,
+    UnknownError,
+)
 from .topic import TopicApiMixin
 from .user import UserApiMixin
 
 log = logging.getLogger(__name__)
 # SQ-7983: lower the log level of retry module to give some feedback
 # see bug report for details
-logging.getLogger('urllib3.util.retry').setLevel(logging.DEBUG)
+logging.getLogger("urllib3.util.retry").setLevel(logging.DEBUG)
 
-warnings.filterwarnings('ignore', category=ImportWarning)
+warnings.filterwarnings("ignore", category=ImportWarning)
 # Disable `ResourceWarning` for python 3 due to unclosed request sessions
 if sys.version_info[0] >= 3:
-    warnings.filterwarnings('ignore', category=ResourceWarning)  # noqa
+    warnings.filterwarnings("ignore", category=ResourceWarning)  # noqa
 
 
 #: Default headers for all requests.
-HEADERS = {'Accept': 'application/json'}
+HEADERS = {"Accept": "application/json"}
 
 #: Default endpoint URLs for the Squirro platform.
 ENDPOINT = {
-    'user': 'https://user-api.squirro.com',
-    'topic': 'https://topic-api.squirro.com',
+    "user": "https://user-api.squirro.com",
+    "topic": "https://topic-api.squirro.com",
 }
 
 #: Version of the Squirro API to be used.
-API_VERSION = 'v0'
+API_VERSION = "v0"
 
 #: Format for datetime values.
-ISO_DATE_FORMAT = '%Y-%m-%dT%H:%M:%S'
+ISO_DATE_FORMAT = "%Y-%m-%dT%H:%M:%S"
 
 #: Default timeout option.
 TIMEOUT_SECS = 55
 
 #: Default retry options.
 RETRY = {
-    'total': 10,
-    'connect': 5,
-    'read': 3,
-    'redirect': 5,
-    'method_whitelist': frozenset([
-        'HEAD', 'GET', 'PUT', 'DELETE', 'OPTIONS', 'TRACE', 'POST']),
-    'status_forcelist': frozenset([502, 503, 504]),
-    'backoff_factor': 1,
+    "total": 10,
+    "connect": 5,
+    "read": 3,
+    "redirect": 5,
+    "method_whitelist": frozenset(
+        ["HEAD", "GET", "PUT", "DELETE", "OPTIONS", "TRACE", "POST"]
+    ),
+    "status_forcelist": frozenset([502, 503, 504]),
+    "backoff_factor": 1,
 }
 
 
@@ -98,46 +107,47 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
         # assign authentication class state
         self.client_id = client_id
         self.client_secret = client_secret
-        self.tenant = kwargs.get('tenant', None)
+        self.tenant = kwargs.get("tenant", None)
 
         self._access_token = None
         self._refresh_token = None
 
         # endpoint URLs
-        self.version = kwargs.get('version', API_VERSION)
-        cluster = kwargs.get('cluster')
+        self.version = kwargs.get("version", API_VERSION)
+        cluster = kwargs.get("cluster")
 
         if cluster:
-            cluster = cluster.rstrip('/')
-            base = '%(cluster)s/api/%(api)s'
-            self.user_api_url = base % {'cluster': cluster, 'api': 'user'}
-            self.topic_api_url = base % {'cluster': cluster, 'api': 'topic'}
+            cluster = cluster.rstrip("/")
+            base = "%(cluster)s/api/%(api)s"
+            self.user_api_url = base % {"cluster": cluster, "api": "user"}
+            self.topic_api_url = base % {"cluster": cluster, "api": "topic"}
 
         else:
-            user_api_url = kwargs.get('user_api_url') or ENDPOINT['user']
-            topic_api_url = kwargs.get('topic_api_url') or ENDPOINT['topic']
+            user_api_url = kwargs.get("user_api_url") or ENDPOINT["user"]
+            topic_api_url = kwargs.get("topic_api_url") or ENDPOINT["topic"]
 
-            self.user_api_url = user_api_url.rstrip('/')
-            self.topic_api_url = topic_api_url.rstrip('/')
+            self.user_api_url = user_api_url.rstrip("/")
+            self.topic_api_url = topic_api_url.rstrip("/")
 
         # retry default options, use values provided by the caller to update
         # the default retry options
         self.retry = RETRY
         for k, v in kwargs.items():
-            if k.startswith('retry_'):
-                self.retry[k.replace('retry_', '')] = v
+            if k.startswith("retry_"):
+                self.retry[k.replace("retry_", "")] = v
 
         # default timeout
         self.timeout_secs = TIMEOUT_SECS
-        kwargs_timeout_secs = kwargs.get('timeout_secs')
+        kwargs_timeout_secs = kwargs.get("timeout_secs")
         if kwargs_timeout_secs:
             self.timeout_secs = kwargs_timeout_secs
 
         # either use the user supplied requests instance or the actual
         # requests module
-        self._requests = kwargs.get('requests', None)
+        self._requests = kwargs.get("requests", None)
         if self._requests is None:
             import requests
+
             self._requests = requests
         self.session = self._new_session()
 
@@ -164,10 +174,17 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
         """Store the received refresh token."""
         self._refresh_token = new_refresh_token
 
-    def authenticate(self, tenant=None, access_token=None, refresh_token=None,
-                     auth_service=None, auth_user=None,
-                     username=None, password=None,
-                     user_information=None):
+    def authenticate(
+        self,
+        tenant=None,
+        access_token=None,
+        refresh_token=None,
+        auth_service=None,
+        auth_user=None,
+        username=None,
+        password=None,
+        user_information=None,
+    ):
         """Authenticate with the Squirro platform by either using access and
         refresh tokens, username and password, or external service name and
         user identifier.
@@ -203,13 +220,13 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
         # assemble base request data
         base = {}
         if self.client_id is not None:
-            base['client_id'] = self.client_id
+            base["client_id"] = self.client_id
         if self.client_secret is not None:
-            base['client_secret'] = self.client_secret
+            base["client_secret"] = self.client_secret
         if self.tenant is not None:
-            base['tenant'] = self.tenant
+            base["tenant"] = self.tenant
         if user_information is not None:
-            base['user_information'] = json.dumps(user_information)
+            base["user_information"] = json.dumps(user_information)
 
         # walk through all possible authentication scenarios
         # - access token
@@ -218,37 +235,35 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
         # - username / password
         if access_token is not None:
             # login by using the access token
-            data = {
-                'grant_type': 'access_token', 'access_token': access_token,
-            }
+            data = {"grant_type": "access_token", "access_token": access_token}
             self._perform_authentication(dict(base, **data))
 
         elif refresh_token is not None:
             # login by using the refresh token
-            data = {
-                'grant_type': 'refresh_token', 'refresh_token': refresh_token,
-            }
+            data = {"grant_type": "refresh_token", "refresh_token": refresh_token}
             self._perform_authentication(dict(base, **data))
 
         elif auth_service is not None and auth_user is not None:
             # by external id
             data = {
-                'grant_type': 'ext_id', 'auth_service': auth_service,
-                'auth_user': auth_user,
+                "grant_type": "ext_id",
+                "auth_service": auth_service,
+                "auth_user": auth_user,
             }
             self._perform_authentication(dict(base, **data))
 
         elif username is not None and password is not None:
             # by username and password
             data = {
-                'grant_type': 'password', 'username': username,
-                'password': password,
+                "grant_type": "password",
+                "username": username,
+                "password": password,
             }
             self._perform_authentication(dict(base, **data))
 
         else:
-            log.debug('empty authentication credentials')
-            raise AuthenticationError(None, 'empty authentication credentials')
+            log.debug("empty authentication credentials")
+            raise AuthenticationError(None, "empty authentication credentials")
 
     def _perform_authentication(self, data):
         """Use the provided parameters to authenticate with the Squirro
@@ -256,7 +271,7 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
         """
 
         # create endpoint url to fetch new tokens
-        url = '%(endpoint)s/oauth2/token' % {'endpoint': self.user_api_url}
+        url = "%(endpoint)s/oauth2/token" % {"endpoint": self.user_api_url}
 
         session = self._new_session()
 
@@ -265,7 +280,7 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
         except self._requests.exceptions.RetryError as ex:
             raise RetryError(None, ex[0])
         except Exception as ex:
-            log.debug('unable to connect to the Squirro platform: %r', ex)
+            log.debug("unable to connect to the Squirro platform: %r", ex)
             raise ConnectionError(None, ex)
 
         res = {}
@@ -274,11 +289,11 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
             if r.content:
                 res = json.loads(r.content)
         except ValueError as ex:
-            log.error('unable to decode JSON: %r', r.content)
+            log.error("unable to decode JSON: %r", r.content)
             raise TransportError(r.status_code, ex)
 
         # perform error handling for known cases
-        error = res.get('error')
+        error = res.get("error")
         if r.status_code == 400:
             raise InputDataError(r.status_code, error)
         elif r.status_code in [403, 404, 410]:
@@ -287,17 +302,16 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
             raise UnknownError(r.status_code, error)
 
         # now we can set the tenant and user identifier as well
-        if res.get('tenant'):
-            self.tenant = res.get('tenant')
-        if res.get('user_id'):
-            self.user_id = res.get('user_id')
-        self.user_permissions = res.get('role_permissions', [])
-        self.token_project_permissions = res.get('project_permissions', None)
-        self.user_information = res.get('user_information', {})
+        if res.get("tenant"):
+            self.tenant = res.get("tenant")
+        if res.get("user_id"):
+            self.user_id = res.get("user_id")
+        self.user_permissions = res.get("role_permissions", [])
+        self.token_project_permissions = res.get("project_permissions", None)
+        self.user_information = res.get("user_information", {})
 
         # all is good and we store the new token
-        self._on_token_refresh(
-            res.get('access_token'), res.get('refresh_token'))
+        self._on_token_refresh(res.get("access_token"), res.get("refresh_token"))
 
     def _on_token_refresh(self, access_token, refresh_token):
         """Method to be called if a new access token has been received for the
@@ -315,8 +329,8 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
         # construct headers to be used for all requests
         headers = dict(HEADERS)
         if access_token is not None:
-            authorization = 'Bearer %(token)s' % {'token': self.access_token}
-            headers['Authorization'] = authorization
+            authorization = "Bearer %(token)s" % {"token": self.access_token}
+            headers["Authorization"] = authorization
 
         session = self._requests.Session()
         session.headers.update(headers)
@@ -325,11 +339,11 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
             session.verify = verify
 
         # add retry capabilities
-        if hasattr(self._requests, 'adapters'):
+        if hasattr(self._requests, "adapters"):
             retries = self._requests.adapters.Retry(**self.retry)
             adapter = self._requests.adapters.HTTPAdapter(max_retries=retries)
-            session.mount('http://', adapter)
-            session.mount('https://', adapter)
+            session.mount("http://", adapter)
+            session.mount("https://", adapter)
 
         return session
 
@@ -342,19 +356,18 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
         # make sure that there is an access token and a refresh token,
         # otherwise we cannot continue
         if self.access_token is None and self.refresh_token is None:
-            raise InputDataError(None, 'missing access and refresh token')
+            raise InputDataError(None, "missing access and refresh token")
 
         # make sure that the tenant is set
         if self.tenant is None:
-            raise InputDataError(None, 'missing tenant')
+            raise InputDataError(None, "missing tenant")
 
         # issue request and retry if authorization fails
         for retry_count in range(2):
             func = getattr(self.session, method)
 
             try:
-                res = func(
-                    url, timeout=self.timeout_secs, **kwargs)
+                res = func(url, timeout=self.timeout_secs, **kwargs)
             except self._requests.exceptions.RetryError as ex:
                 raise RetryError(None, ex[0])
 
@@ -367,7 +380,7 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
                 if not successful:
                     break
 
-                log.debug('retrying request %r %r', method, url)
+                log.debug("retrying request %r %r", method, url)
 
             else:
                 break
@@ -382,7 +395,7 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
 
         # first we make sure that we have a refresh token
         if not self.refresh_token:
-            log.debug('unable to refresh access token, missing refresh token')
+            log.debug("unable to refresh access token, missing refresh token")
             return ret
 
         # login via the refresh token
@@ -404,12 +417,16 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
                     ret = True
                     break
 
-                log.info('Access token %r not refreshed on behalf of '
-                         'refresh token %r. Retry number %d',
-                         self.access_token, self.refresh_token, try_count)
+                log.info(
+                    "Access token %r not refreshed on behalf of "
+                    "refresh token %r. Retry number %d",
+                    self.access_token,
+                    self.refresh_token,
+                    try_count,
+                )
 
         except Exception as ex:
-            log.exception('unable to refresh access token: %r', ex)
+            log.exception("unable to refresh access token: %r", ex)
 
         return ret
 
@@ -428,7 +445,7 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
             if res.content:
                 data = json.loads(res.content)
         except ValueError as ex:
-            log.error('unable to decode JSON: %r', res.content)
+            log.error("unable to decode JSON: %r", res.content)
             raise TransportError(None, ex)
 
         # if the status code matches to what is expected we return the data
@@ -436,7 +453,7 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
             return data
 
         # raise the appropriate exception
-        error = data.get('error')
+        error = data.get("error")
         if res.status_code == 400:
             raise ClientError(res.status_code, error, data)
 
@@ -482,9 +499,8 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
         if not hasattr(sys, "frozen"):
             # The `frozen` attribute is set in py2exe
             return None
-        exe_dir = os.path.dirname(str(sys.executable,
-                                      sys.getfilesystemencoding()))
-        ca_bundle = os.path.join(exe_dir, 'cacert', 'cacert.pem')
+        exe_dir = os.path.dirname(str(sys.executable, sys.getfilesystemencoding()))
+        ca_bundle = os.path.join(exe_dir, "cacert", "cacert.pem")
         if not os.path.exists(ca_bundle):
             return False
         return ca_bundle
