@@ -1,7 +1,4 @@
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import unicode_literals
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 import base64
 import json
@@ -14,10 +11,17 @@ log = logging.getLogger(__name__)
 
 class ProjectsMixin(object):
 
-    PROJECT_ATTRIBUTES = set([
-        'default_search', 'title', 'default_sort', 'locator',
-        'guide_completed_steps', 'theme'
-    ])
+    PROJECT_ATTRIBUTES = set(
+        [
+            "default_search",
+            "title",
+            "default_sort",
+            "locator",
+            "guide_completed_steps",
+            "theme",
+            "integration_dashboards",
+        ]
+    )
 
     def get_user_projects(self):
         """Get projects for the provided user.
@@ -34,12 +38,13 @@ class ProjectsMixin(object):
 
         """
 
-        url = '%(ep)s/%(version)s/%(tenant)s/projects' % {
-            'ep': self.topic_api_url, 'version': self.version,
-            'tenant': self.tenant
+        url = "%(ep)s/%(version)s/%(tenant)s/projects" % {
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
         }
 
-        res = self._perform_request('get', url)
+        res = self._perform_request("get", url)
         return self._process_response(res)
 
     def get_project(self, project_id):
@@ -57,15 +62,19 @@ class ProjectsMixin(object):
 
         """
 
-        url = '%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s' % {
-            'ep': self.topic_api_url, 'version': self.version,
-            'tenant': self.tenant, 'project_id': project_id}
+        url = "%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s" % {
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+        }
 
-        res = self._perform_request('get', url)
+        res = self._perform_request("get", url)
         return self._process_response(res)
 
-    def new_project(self, title, owner_id=None, locator=None,
-                    default_sort=None, project_id=None):
+    def new_project(
+        self, title, owner_id=None, locator=None, default_sort=None, project_id=None
+    ):
         """Create a new project.
 
         :param title: Project title.
@@ -95,27 +104,54 @@ class ProjectsMixin(object):
             {u'id': u'gd9eIipOQ-KobU0SwJ8VcQ'}
         """
 
-        url = '%(ep)s/%(version)s/%(tenant)s/projects' % {
-            'ep': self.topic_api_url, 'version': self.version,
-            'tenant': self.tenant}
+        url = "%(ep)s/%(version)s/%(tenant)s/projects" % {
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+        }
 
         # build data
-        data = {'title': title}
+        data = {"title": title}
         if project_id is not None:
-            data['project_id'] = project_id
+            data["project_id"] = project_id
         if owner_id is not None:
-            data['owner_id'] = owner_id
+            data["owner_id"] = owner_id
         if locator is not None:
-            data['locator'] = json.dumps(locator)
+            data["locator"] = json.dumps(locator)
         if default_sort is not None:
-            data['default_sort'] = json.dumps(default_sort)
+            data["default_sort"] = json.dumps(default_sort)
 
-        res = self._perform_request('post', url, data=data)
+        res = self._perform_request("post", url, data=data)
         return self._process_response(res, [201])
 
-    def new_project_from_template(self, title, locator=None,
-                                  template_name=None, template_path=None,
-                                  project_id=None):
+    def new_project_from_template(
+        self,
+        title,
+        locator=None,
+        template_name=None,
+        template_path=None,
+        project_id=None,
+        keep_ids=False,
+        import_dashboards=True,
+        import_dashboard_widgets=True,
+        import_dashboard_loaders=True,
+        import_email_templates=True,
+        import_pipeline_workflows=True,
+        import_enrichments=True,
+        import_enrichment_pipelets=True,
+        import_facets=True,
+        import_synonyms=True,
+        import_machinelearning_workflows=True,
+        import_machinelearning_jobs=True,
+        import_machinelearning_models=True,
+        import_project_configuration=True,
+        import_project_configuration_values=True,
+        import_smartfilters=True,
+        import_sources=True,
+        import_sources_dataloader_plugins=True,
+        import_trends=True,
+        import_items=True,
+    ):
         """Create a new project from a project template.
 
         :param title: Project title.
@@ -138,6 +174,52 @@ class ProjectsMixin(object):
             project with the provided id. The length of the parameter must
             be 22 characters. Useful when exporting and importing projects
             across multiple Squirro servers.
+        :param keep_ids: Boolean. Whether to try to create entities
+            (project_id, dashboards, sources) with the same ID as the original's project
+        :param import_dashboards: Boolean. Whether to include the dashboards,
+            defaults to `True`.
+        :param import_dashboard_widgets: Boolean. Whether to include the
+            dashboards custom widgets. This only applies if `import_dashboards`
+            is set to `True`. Defaults to `True`.
+        :param import_dashboard_loaders: Boolean. Whether to include the
+            dashboards loaders. This only applies if `import_dashboards`
+            is set to `True`. Defaults to `True`.
+        :param import_email_templates: Boolean. Whether to include the email
+            templates. Defaults to `True`. NOT USED AT THE MOMENT
+        :param import_pipeline_workflows: Boolean. Whether to include the
+            pipeline workflows. Defaults to `True`.
+        :param import_enrichments: Boolean. Whether to include the enrichments,
+            defaults to `True`.
+        :param import_enrichment_pipelets: Boolean. Whether to include the
+            pipelets together with the enrichments. This only applies of the
+            `import_enrichments` is set to `True`. Defaults to `True`.
+            defaults to `True`.
+        :param import_facets: Boolean. Whether to include the facets,
+            defaults to `True`. Needs the `import_synonyms` to be set to `True`
+            also.
+        :param import_synonyms: Boolean. Whether to include the synonyms lists,
+            defaults to 'True'.
+        :param import_machinelearning_workflows: Boolean. Whether to include
+            the machinelearning workflows. Defaults to `True`.
+        :param import_machinelearning_jobs: Boolean. Whether to include the
+            machinelearning jobs. Defaults to `True`.
+        :param import_machinelearning_models: Boolean. Whether to include the
+            machinelearning models. Defaults to `True`.
+        :param import_project_configuration: Boolean. Whether to include the
+            project configuration, defaults to `True`.
+        :param import_project_configuration_values: Boolean. Whether to include
+            the import_project_configuration_values, defaults to `True`.
+        :param import_smartfilters: Boolean. Whether to include the
+            smartfilters, defaults to `True`.
+        :param import_sources: Boolean. Whether to include the sources,
+            defaults to `True`.
+        :param import_sources_dataloader_plugins: Boolean. Whether to include
+            the dataloaders, defaults to `True`.
+        :param import_trends: Boolean. Whether to include the trends,
+            defaults to `True`.
+        :param import_items: Boolean. Whether to include the items,
+            defaults to `True`. Needs the `import_facets` to be set to `True`
+            also.
         :returns: A dictionary which contains the project identifier.
 
         Example::
@@ -147,23 +229,53 @@ class ProjectsMixin(object):
             {u'id': u'gd9eIipOQ-KobU0SwJ8VcQ'}
         """
 
-        url = '%(ep)s/%(version)s/%(tenant)s/projects_from_template' % {
-            'ep': self.topic_api_url, 'version': self.version,
-            'tenant': self.tenant}
+        url = "%(ep)s/%(version)s/%(tenant)s/projects_from_template" % {
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+        }
 
         # build data
-        data = {'title': title}
+        data = {"title": title}
         if template_name is not None:
-            data['template_name'] = template_name
+            data["template_name"] = template_name
         if template_path is not None:
-            data['template_path'] = template_path
+            data["template_path"] = template_path
         if project_id is not None:
-            data['project_id'] = project_id
+            data["project_id"] = project_id
         if locator is not None:
-            data['locator'] = json.dumps(locator)
-        data['token'] = self.refresh_token
+            data["locator"] = json.dumps(locator)
+        if keep_ids:
+            # Even though eventually keep_ids will end up as part of import_options,
+            # let's keep the separation for the user's convenience
+            data["keep_ids"] = True
 
-        res = self._perform_request('post', url, data=data)
+        import_options = {
+            "import_dashboards": import_dashboards,
+            "import_dashboard_widgets": import_dashboard_widgets,
+            "import_dashboard_loaders": import_dashboard_loaders,
+            # 'import_email_templates': import_email_templates,
+            "import_enrichments": import_enrichments,
+            "import_enrichment_pipelets": import_enrichment_pipelets,
+            "import_facets": import_facets,
+            "import_machinelearning_workflows": import_machinelearning_workflows,
+            "import_machinelearning_jobs": import_machinelearning_jobs,
+            "import_machinelearning_models": import_machinelearning_models,
+            "import_pipeline_workflows": import_pipeline_workflows,
+            "import_project_configuration": import_project_configuration,
+            "import_project_configuration_values": import_project_configuration_values,
+            "import_smartfilters": import_smartfilters,
+            "import_sources": import_sources,
+            "import_sources_dataloader_plugins": import_sources_dataloader_plugins,
+            "import_trends": import_trends,
+            "import_items": import_items,
+            "import_synonyms": import_synonyms,
+        }
+        data["import_options"] = json.dumps(import_options)
+
+        data["token"] = self.refresh_token
+
+        res = self._perform_request("post", url, data=data)
         return self._process_response(res, [201])
 
     def modify_project(self, project_id, **kwargs):
@@ -181,9 +293,12 @@ class ProjectsMixin(object):
             ...                       title='My Other Project')
 
         """
-        url = '%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s' % {
-            'ep': self.topic_api_url, 'version': self.version,
-            'tenant': self.tenant, 'project_id': project_id}
+        url = "%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s" % {
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+        }
 
         # build data
         data = {}
@@ -191,10 +306,9 @@ class ProjectsMixin(object):
             if key in kwargs:
                 data[key] = kwargs[key]
 
-        headers = {'Content-Type': 'application/json'}
+        headers = {"Content-Type": "application/json"}
 
-        res = self._perform_request(
-            'put', url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("put", url, data=json.dumps(data), headers=headers)
         return self._process_response(res, [201, 204])
 
     def delete_project(self, project_id):
@@ -208,15 +322,23 @@ class ProjectsMixin(object):
 
         """
 
-        url = '%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s' % {
-            'ep': self.topic_api_url, 'version': self.version,
-            'tenant': self.tenant, 'project_id': project_id}
+        url = "%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s" % {
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+        }
 
-        res = self._perform_request('delete', url)
+        res = self._perform_request("delete", url)
         self._process_response(res, [204])
 
-    def reset_project(self, project_id, reset_dashboards=None,
-                      reset_elasticsearch_index=None, reset_facets=None):
+    def reset_project(
+        self,
+        project_id,
+        reset_dashboards=None,
+        reset_elasticsearch_index=None,
+        reset_facets=None,
+    ):
         """Resets different entities of a project based on boolean flags.
 
         :param project_id: Project identifier.
@@ -242,46 +364,54 @@ class ProjectsMixin(object):
 
         """
 
-        url = '%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s/reset' % {
-            'ep': self.topic_api_url, 'version': self.version,
-            'tenant': self.tenant, 'project_id': project_id}
+        url = "%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s/reset" % {
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+        }
 
-        headers = {'Content-Type': 'application/json'}
+        headers = {"Content-Type": "application/json"}
 
         args = {
-            'reset_dashboards': reset_dashboards,
-            'reset_elasticsearch_index': reset_elasticsearch_index,
-            'reset_facets': reset_facets
+            "reset_dashboards": reset_dashboards,
+            "reset_elasticsearch_index": reset_elasticsearch_index,
+            "reset_facets": reset_facets,
         }
         data = dict([(k, v) for k, v in args.items() if v is not None])
 
         if data:
             res = self._perform_request(
-                'post', url, data=json.dumps(data), headers=headers)
+                "post", url, data=json.dumps(data), headers=headers
+            )
         else:
             res = {}
         self._process_response(res, [200])
 
-    def export_project(self, project_id,
-                       export_dashboards=True,
-                       export_dashboard_widgets=True,
-                       export_dashboard_loaders=True,
-                       export_email_templates=True,
-                       export_pipeline_workflows=True,
-                       export_enrichments=True,
-                       export_enrichment_pipelets=True,
-                       export_facets=True,
-                       export_machinelearning_workflows=True,
-                       export_machinelearning_jobs=True,
-                       export_machinelearning_models=True,
-                       export_project_configuration=True,
-                       export_project_configuration_values=True,
-                       export_smartfilters=True,
-                       export_sources=True,
-                       export_sources_dataloader_plugins=True,
-                       export_trends=True,
-                       export_items=False,
-                       export_items_config=None):
+    def export_project(
+        self,
+        project_id,
+        export_dashboards=True,
+        export_dashboard_widgets=True,
+        export_dashboard_loaders=True,
+        export_email_templates=True,
+        export_pipeline_workflows=True,
+        export_enrichments=True,
+        export_enrichment_pipelets=True,
+        export_facets=True,
+        export_synonyms=True,
+        export_machinelearning_workflows=True,
+        export_machinelearning_jobs=True,
+        export_machinelearning_models=True,
+        export_project_configuration=True,
+        export_project_configuration_values=True,
+        export_smartfilters=True,
+        export_sources=True,
+        export_sources_dataloader_plugins=True,
+        export_trends=True,
+        export_items=False,
+        export_items_config=None,
+    ):
         """Exports parts or all configuration and metadata of a project.
 
         The following entities can be exported:
@@ -335,7 +465,9 @@ class ProjectsMixin(object):
             pipelets together with the enrichments. This only applies of the
             `export_enrichments` is set to `True`. Defaults to `True`.
         :param export_facets: Boolean. Whether to include the facets,
-            defaults to `True`.
+            defaults to `True`. Needs `export_synonyms` to be True
+        :param export_synonyms: Boolean. Whether to include the synonyms lists,
+            defaults to 'True'
         :param export_machinelearning_workflows: Boolean. Whether to include
             the machinelearning workflows. Defaults to `True`.
         :param export_machinelearning_jobs: Boolean. Whether to include the
@@ -369,48 +501,47 @@ class ProjectsMixin(object):
             For saving the archive, refer to get_project_export method
         """
 
-        url = '%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s/export' % {
-            'ep': self.topic_api_url, 'version': self.version,
-            'tenant': self.tenant, 'project_id': project_id}
+        url = "%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s/export" % {
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+        }
 
-        headers = {'Content-Type': 'application/json'}
+        headers = {"Content-Type": "application/json"}
 
         export_options = {
-            'export_dashboards': export_dashboards,
-            'export_dashboard_widgets': export_dashboard_widgets,
-            'export_dashboard_loaders': export_dashboard_loaders,
+            "export_dashboards": export_dashboards,
+            "export_dashboard_widgets": export_dashboard_widgets,
+            "export_dashboard_loaders": export_dashboard_loaders,
             # 'export_email_templates': export_email_templates,
-            'export_enrichments': export_enrichments,
-            'export_enrichment_pipelets': export_enrichment_pipelets,
-            'export_facets': export_facets,
-            'export_machinelearning_workflows':
-                export_machinelearning_workflows,
-            'export_machinelearning_jobs': export_machinelearning_jobs,
-            'export_machinelearning_models': export_machinelearning_models,
-            'export_pipeline_workflows': export_pipeline_workflows,
-            'export_project_configuration': export_project_configuration,
-            'export_project_configuration_values':
-                export_project_configuration_values,
-            'export_smartfilters': export_smartfilters,
-            'export_sources': export_sources,
-            'export_sources_dataloader_plugins':
-                export_sources_dataloader_plugins,
-            'export_trends': export_trends,
-            'export_items': export_items,
-            'export_items_config': export_items_config
+            "export_enrichments": export_enrichments,
+            "export_enrichment_pipelets": export_enrichment_pipelets,
+            "export_facets": export_facets,
+            "export_machinelearning_workflows": export_machinelearning_workflows,
+            "export_machinelearning_jobs": export_machinelearning_jobs,
+            "export_machinelearning_models": export_machinelearning_models,
+            "export_pipeline_workflows": export_pipeline_workflows,
+            "export_project_configuration": export_project_configuration,
+            "export_project_configuration_values": export_project_configuration_values,
+            "export_smartfilters": export_smartfilters,
+            "export_sources": export_sources,
+            "export_sources_dataloader_plugins": export_sources_dataloader_plugins,
+            "export_trends": export_trends,
+            "export_items": export_items,
+            "export_synonyms": export_synonyms,
+            "export_items_config": export_items_config,
         }
-        export_options['token'] = self.refresh_token
+        export_options["token"] = self.refresh_token
 
-        data = dict([(k, v) for k, v in export_options.items()
-                     if v is not None])
+        data = dict([(k, v) for k, v in export_options.items() if v is not None])
 
-        res = self._perform_request(
-            'post', url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
 
         if res.status_code != 201:
             res.raise_for_status()
 
-        return {'data': res.content, 'headers': res.headers}
+        return {"data": res.content, "headers": res.headers}
 
     def get_project_export(self, project_id, export_id, write_to_disk=False):
         """Retrieve a project export.
@@ -439,49 +570,58 @@ class ProjectsMixin(object):
                 f.write(ret.get('data'))
         """
 
-        url = '%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s/export' % {
-            'ep': self.topic_api_url, 'version': self.version,
-            'tenant': self.tenant, 'project_id': project_id}
+        url = "%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s/export" % {
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+        }
 
-        headers = {'Content-Type': 'application/json'}
+        headers = {"Content-Type": "application/json"}
 
         res = self._perform_request(
-            'get', url, params={'export_id': export_id}, headers=headers)
+            "get", url, params={"export_id": export_id}, headers=headers
+        )
 
         if res.status_code == 201:
-            return {'data': None, 'headers': res.headers,
-                    'status': 'processing'}
+            return {"data": None, "headers": res.headers, "status": "processing"}
         elif res.status_code != 200:
             res.raise_for_status()
 
         if write_to_disk:
             exported_file = self._get_file_name(res)
-            with open(exported_file, 'wb') as exported_project:
+            with open(exported_file, "wb") as exported_project:
                 exported_project.write(res.content)
-                print('Exported project to ./{}'.format(exported_file))
+                print("Exported project to ./{}".format(exported_file))
             return
 
-        return {'data': res.content, 'headers': res.headers, 'status': 'done'}
+        return {"data": res.content, "headers": res.headers, "status": "done"}
+
+    def import_project(
+        self,
+        project_id,
+        project_archive,
+        import_dashboards=True,
+        import_dashboard_widgets=True,
+        import_dashboard_loaders=True,
+        import_email_templates=True,
+        import_pipeline_workflows=True,
+        import_enrichments=True,
+        import_enrichment_pipelets=True,
+        import_facets=True,
+        import_synonyms=True,
+        import_machinelearning_workflows=True,
+        import_machinelearning_jobs=True,
+        import_machinelearning_models=True,
+        import_project_configuration=True,
+        import_project_configuration_values=True,
+        import_smartfilters=True,
+        import_sources=True,
+        import_sources_dataloader_plugins=True,
+        import_trends=True,
+        import_items=True,
+    ):
 
-    def import_project(self, project_id, project_archive,
-                       import_dashboards=True,
-                       import_dashboard_widgets=True,
-                       import_dashboard_loaders=True,
-                       import_email_templates=True,
-                       import_pipeline_workflows=True,
-                       import_enrichments=True,
-                       import_enrichment_pipelets=True,
-                       import_facets=True,
-                       import_machinelearning_workflows=True,
-                       import_machinelearning_jobs=True,
-                       import_machinelearning_models=True,
-                       import_project_configuration=True,
-                       import_project_configuration_values=True,
-                       import_smartfilters=True,
-                       import_sources=True,
-                       import_sources_dataloader_plugins=True,
-                       import_trends=True,
-                       import_items=True):
         """Imports parts or all configuration and metadata of a project.
 
         The following entities can be imported:
@@ -532,7 +672,10 @@ class ProjectsMixin(object):
             pipelets together with the enrichments. This only applies of the
             `import_enrichments` is set to `True`. Defaults to `True`.
         :param import_facets: Boolean. Whether to include the facets,
-            defaults to `True`.
+            defaults to `True`. Needs the `import_synonyms` to be set to `True`
+            also.
+        :param import_synonyms: Boolean. Whether to include the synonyms lists,
+            defaults to 'True'.
         :param import_machinelearning_workflows: Boolean. Whether to include
             the machinelearning workflows. Defaults to `True`.
         :param import_machinelearning_jobs: Boolean. Whether to include the
@@ -554,7 +697,6 @@ class ProjectsMixin(object):
         :param import_items: Boolean. Whether to include the items,
             defaults to `True`. Needs the `import_facets` to be set to `True`
             also.
-
         Example::
 
             >>> res = client.import_project(
@@ -562,58 +704,57 @@ class ProjectsMixin(object):
                     {'dashboards': False})
         """
 
-        url = '%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s/import' % {
-            'ep': self.topic_api_url, 'version': self.version,
-            'tenant': self.tenant, 'project_id': project_id}
+        url = "%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s/import" % {
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+        }
 
-        headers = {'Content-Type': 'application/json'}
+        headers = {"Content-Type": "application/json"}
 
         import_options = {
-            'import_dashboards': import_dashboards,
-            'import_dashboard_widgets': import_dashboard_widgets,
-            'import_dashboard_loaders': import_dashboard_loaders,
+            "import_dashboards": import_dashboards,
+            "import_dashboard_widgets": import_dashboard_widgets,
+            "import_dashboard_loaders": import_dashboard_loaders,
             # 'import_email_templates': import_email_templates,
-            'import_enrichments': import_enrichments,
-            'import_enrichment_pipelets': import_enrichment_pipelets,
-            'import_facets': import_facets,
-            'import_machinelearning_workflows':
-                import_machinelearning_workflows,
-            'import_machinelearning_jobs': import_machinelearning_jobs,
-            'import_machinelearning_models': import_machinelearning_models,
-            'import_pipeline_workflows': import_pipeline_workflows,
-            'import_project_configuration': import_project_configuration,
-            'import_project_configuration_values':
-                import_project_configuration_values,
-            'import_smartfilters': import_smartfilters,
-            'import_sources': import_sources,
-            'import_sources_dataloader_plugins':
-                import_sources_dataloader_plugins,
-            'import_trends': import_trends,
-            'import_items': import_items
+            "import_enrichments": import_enrichments,
+            "import_enrichment_pipelets": import_enrichment_pipelets,
+            "import_facets": import_facets,
+            "import_machinelearning_workflows": import_machinelearning_workflows,
+            "import_machinelearning_jobs": import_machinelearning_jobs,
+            "import_machinelearning_models": import_machinelearning_models,
+            "import_pipeline_workflows": import_pipeline_workflows,
+            "import_project_configuration": import_project_configuration,
+            "import_project_configuration_values": import_project_configuration_values,
+            "import_smartfilters": import_smartfilters,
+            "import_sources": import_sources,
+            "import_sources_dataloader_plugins": import_sources_dataloader_plugins,
+            "import_trends": import_trends,
+            "import_items": import_items,
+            "import_synonyms": import_synonyms,
         }
-        import_options['token'] = self.refresh_token
+        import_options["token"] = self.refresh_token
 
-        data = dict(
-            [(k, v) for k, v in import_options.items() if v is not None])
+        data = dict([(k, v) for k, v in import_options.items() if v is not None])
 
-        with open(project_archive, 'rb') as f:
-            data['archive'] = base64.b64encode(f.read()).decode('utf-8')
+        with open(project_archive, "rb") as f:
+            data["archive"] = base64.b64encode(f.read()).decode("utf-8")
 
-        res = self._perform_request(
-            'post', url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
 
         if res.status_code != 201:
             res.raise_for_status()
 
-        return {'data': res.content, 'headers': res.headers}
+        return {"data": res.content, "headers": res.headers}
 
     def _get_file_name(self, res):
         # Default file name
-        file_name = 'exported_project.sqproj'
+        file_name = "exported_project.sqproj"
 
         # File name from the header
-        cd_header = res.headers.get('Content-Disposition')
+        cd_header = res.headers.get("Content-Disposition")
         if cd_header:
-            file_name = re.findall('filename=(.+)', cd_header)[0]
+            file_name = re.findall("filename=(.+)", cd_header)[0]
 
         return file_name
